from django.contrib.auth.models import User
from django.shortcuts import render, render_to_response
from django.views import generic
from django.views.generic.edit import CreateView, FormView
# Create your views here.
from accounts.forms import LoginForm
from accounts.models import Accounts, Players
from accounts.utils import LoginHelper


class RegisterAccountView(CreateView):
    model = Accounts
    fields = ['name', 'password', 'email']
    template_name = 'register_account.html'

    def form_valid(self, form):
        self.object = form.save(commit=False)

        # create django user
        u, created = User.objects.get_or_create(
            username=self.object.name,
            email=self.object.email,
        )
        if created:
            u.set_password(self.object.password)
            u.save()
            # create tibia account with sha1 hashed password
            hashed_password = LoginHelper.hash_password(self.object.password)
            self.object.password = hashed_password
            self.object.linked_django_user = u
            self.object.save()
        return render_to_response(self.template_name, self.get_context_data())

class IndexView(generic.ListView):
    template_name = 'index.html'
    context_object_name = 'best_players'

    def get_queryset(self):
        return Players.objects.filter(group_id=1).order_by('-level').values('name', 'level')[:10]